// <copyright file="GetTreeCommand.cs" company="Selenium Committers">
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
// </copyright>

namespace OpenQA.Selenium.BiDi.BrowsingContext;

internal sealed class GetTreeCommand(GetTreeParameters @params)
    : Command<GetTreeParameters, GetTreeResult>(@params, "browsingContext.getTree");

internal sealed record GetTreeParameters(long? MaxDepth, BrowsingContext? Root) : Parameters;

public sealed record GetTreeOptions : CommandOptions
{
    public long? MaxDepth { get; init; }

    public BrowsingContext? Root { get; init; }
}

public sealed record ContextGetTreeOptions : CommandOptions
{
    public long? MaxDepth { get; init; }

    internal static GetTreeOptions WithContext(ContextGetTreeOptions? options, BrowsingContext context) => new()
    {
        Root = context,
        MaxDepth = options?.MaxDepth,
        Timeout = options?.Timeout
    };
}

public sealed record GetTreeResult(IReadOnlyList<BrowsingContextInfo> Contexts) : EmptyResult;
